Package: regsplice
Version: 1.36.0
Title: L1-regularization based methods for detection of differential
        splicing
Description: Statistical methods for detection of differential splicing 
    (differential exon usage) in RNA-seq and exon microarray data, using 
    L1-regularization (lasso) to improve power.
Authors@R: person("Lukas M.", "Weber", email = "lmweb012@gmail.com", role = c("aut", "cre"))
Author: Lukas M. Weber [aut, cre]
Maintainer: Lukas M. Weber <lmweb012@gmail.com>
URL: https://github.com/lmweber/regsplice
BugReports: https://github.com/lmweber/regsplice/issues
License: MIT + file LICENSE
Imports: glmnet, SummarizedExperiment, S4Vectors, limma, edgeR, stats,
        pbapply, utils, methods
Suggests: testthat, BiocStyle, knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.1.0
biocViews: ImmunoOncology, AlternativeSplicing, DifferentialExpression,
        DifferentialSplicing, Sequencing, RNASeq, Microarray,
        ExonArray, ExperimentalDesign, Software
Collate: 'class_RegspliceResults.R' 'class_RegspliceData.R' 'LRTests.R'
        'createDesignMatrix.R' 'filterLowCounts.R' 'filterZeros.R'
        'fitting_functions_multiple_genes.R'
        'fitting_functions_single_gene.R' 'helper_functions.R'
        'initializeResults.R' 'regsplice_wrapper.R'
        'runNormalization.R' 'runVoom.R' 'summaryTable.R'
git_url: https://git.bioconductor.org/packages/regsplice
git_branch: RELEASE_3_22
git_last_commit: d9c8d76
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:00:59 UTC; biocbuild
