# Generated by roxygen2: do not edit by hand

export(LRTests)
export(LR_stats)
export(RegspliceData)
export(RegspliceResults)
export(countsData)
export(createDesignMatrix)
export(df_tests)
export(filterLowCounts)
export(filterZeros)
export(fitFullMultiple)
export(fitNullMultiple)
export(fitRegMultiple)
export(gene_IDs)
export(initializeResults)
export(p_adj)
export(p_vals)
export(regsplice)
export(runNormalization)
export(runVoom)
export(summaryTable)
export(weightsData)
exportClasses(RegspliceData)
exportClasses(RegspliceResults)
exportMethods("[")
exportMethods(LR_stats)
exportMethods(assays)
exportMethods(colData)
exportMethods(countsData)
exportMethods(df_tests)
exportMethods(gene_IDs)
exportMethods(p_adj)
exportMethods(p_vals)
exportMethods(rowData)
exportMethods(weightsData)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,SimpleList)
importFrom(SummarizedExperiment,"assays<-")
importFrom(SummarizedExperiment,"colData<-")
importFrom(SummarizedExperiment,Assays)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(edgeR,calcNormFactors)
importFrom(glmnet,cv.glmnet)
importFrom(limma,voom)
importFrom(methods,callNextMethod)
importFrom(methods,is)
importFrom(methods,new)
importFrom(pbapply,pblapply)
importFrom(pbapply,pboptions)
importFrom(stats,deviance)
importFrom(stats,glm)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(utils,head)
